@@ -1,25 +1,12 @@
-/********************************************************************
-Copyright 2014 Martin Gräßlin <mgraesslin@kde.org>
-Copyright 2015 Sebastian Kügler <sebas@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2015 Sebastian Kügler <sebas@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 // Qt
-#include <QtTest/QtTest>
+#include <QTest>
+#include <QSignalSpy>
 // KWin
 #include "../../src/client/connection_thread.h"
 #include "../../src/client/event_queue.h"
@@ -44,7 +31,9 @@ private Q_SLOTS:
 
     void testRegistry();
     void testModeChanges();
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 50)
     void testScaleChange_legacy();
+#endif
     void testScaleChange();
     void testColorCurvesChange();
 
@@ -207,7 +196,10 @@ void TestWaylandOutputDevice::testRegistry()
     QCOMPARE(output.physicalSize(), QSize());
     QCOMPARE(output.pixelSize(), QSize());
     QCOMPARE(output.refreshRate(), 0);
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 50)
     QCOMPARE(output.scale(), 1);
+#endif
+    QCOMPARE(output.scaleF(), 1.0);
     QCOMPARE(output.colorCurves().red, QVector<quint16>());
     QCOMPARE(output.colorCurves().green, QVector<quint16>());
     QCOMPARE(output.colorCurves().blue, QVector<quint16>());
@@ -233,7 +225,10 @@ void TestWaylandOutputDevice::testRegistry()
     QCOMPARE(output.physicalSize(), QSize(200, 100));
     QCOMPARE(output.pixelSize(), QSize(1024, 768));
     QCOMPARE(output.refreshRate(), 60000);
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 50)
     QCOMPARE(output.scale(), 1);
+#endif
+    QCOMPARE(output.scaleF(), 1.0);
     QCOMPARE(output.colorCurves().red, m_initColorCurves.red);
     QCOMPARE(output.colorCurves().green, m_initColorCurves.green);
     QCOMPARE(output.colorCurves().blue, m_initColorCurves.blue);
@@ -346,6 +341,7 @@ void TestWaylandOutputDevice::testModeChanges()
     QCOMPARE(output.pixelSize(), QSize(1280, 1024));
 }
 
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 50)
 void TestWaylandOutputDevice::testScaleChange_legacy()
 {
     KWayland::Client::Registry registry;
@@ -366,6 +362,7 @@ void TestWaylandOutputDevice::testScaleChange_legacy()
     wl_display_flush(m_connection->display());
     QVERIFY(outputChanged.wait());
     QCOMPARE(output.scale(), 1);
+    QCOMPARE(output.scaleF(), 1.0);
 
     // change the scale
     outputChanged.clear();
@@ -382,6 +379,7 @@ void TestWaylandOutputDevice::testScaleChange_legacy()
     QCOMPARE(output.scale(), 4);
     QCOMPARE(output.scaleF(), 4.0);
 }
+#endif
 
 void TestWaylandOutputDevice::testScaleChange()
 {
@@ -408,14 +406,18 @@ void TestWaylandOutputDevice::testScaleChange()
     outputChanged.clear();
     m_serverOutputDevice->setScaleF(2.2);
     QVERIFY(outputChanged.wait());
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 50)
     QCOMPARE(output.scale(), 2); //check backwards compatibility works
+#endif
     QCOMPARE(wl_fixed_from_double(output.scaleF()), wl_fixed_from_double(2.2));
 
     // change once more
     outputChanged.clear();
     m_serverOutputDevice->setScaleF(4.9);
     QVERIFY(outputChanged.wait());
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 50)
     QCOMPARE(output.scale(), 5);
+#endif
     QCOMPARE(wl_fixed_from_double(output.scaleF()), wl_fixed_from_double(4.9));
 }
 
