@@ -1,24 +1,12 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 // Qt
-#include <QtTest/QtTest>
+#include <QAbstractEventDispatcher>
+#include <QSignalSpy>
+#include <QTest>
 // KWin
 #include "../../src/client/blur.h"
 #include "../../src/client/contrast.h"
@@ -65,10 +53,10 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include <wayland-server-decoration-client-protocol.h>
 #include <wayland-text-input-v0-client-protocol.h>
 #include <wayland-text-input-v2-client-protocol.h>
-#include <wayland-xdg-shell-v5-client-protocol.h>
 #include <wayland-relativepointer-unstable-v1-client-protocol.h>
 #include <wayland-pointer-gestures-unstable-v1-client-protocol.h>
 #include <wayland-pointer-constraints-unstable-v1-client-protocol.h>
+#include "../../src/compat/wayland-xdg-shell-v5-client-protocol.h"
 
 class TestWaylandRegistry : public QObject
 {
@@ -347,7 +335,7 @@ void TestWaylandRegistry::testBindTextInputManagerUnstableV2()
 
 void TestWaylandRegistry::testBindXdgShellUnstableV5()
 {
-    TEST_BIND(KWayland::Client::Registry::Interface::XdgShellUnstableV5, SIGNAL(xdgShellUnstableV5Announced(quint32,quint32)), bindXdgShellUnstableV5, xdg_shell_destroy)
+    TEST_BIND(KWayland::Client::Registry::Interface::XdgShellUnstableV5, SIGNAL(xdgShellUnstableV5Announced(quint32,quint32)), bindXdgShellUnstableV5, zxdg_shell_v5_destroy)
 }
 
 void TestWaylandRegistry::testBindRelativePointerManagerUnstableV1()
@@ -598,7 +586,7 @@ void TestWaylandRegistry::testOutOfSyncRemoval()
 
     //server removes the global
     //(simultaneously) the client legimitely uses the bound resource to the global
-    //client then gets the server events...it should no-op, not be a protcol error
+    //client then gets the server events...it should no-op, not be a protocol error
 
     using namespace KWayland::Client;
     KWayland::Client::ConnectionThread connection;
@@ -641,7 +629,7 @@ void TestWaylandRegistry::testOutOfSyncRemoval()
     QVERIFY(blurRemovedSpy.count() == 0);
 
     //use the in the client
-    blurManager->createBlur(surface.data(), 0);
+    blurManager->createBlur(surface.data(), nullptr);
 
     //now process events,
     QVERIFY(blurRemovedSpy.wait());
@@ -656,7 +644,7 @@ void TestWaylandRegistry::testOutOfSyncRemoval()
     QVERIFY(contrastRemovedSpy.count() == 0);
 
     //use the in the client
-    contrastManager->createContrast(surface.data(), 0);
+    contrastManager->createContrast(surface.data(), nullptr);
 
     //now process events,
     QVERIFY(contrastRemovedSpy.wait());
