@@ -1,26 +1,13 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 // Qt
-#include <QtTest/QtTest>
+#include <QTest>
 #include <QImage>
 #include <QPainter>
+#include <QSignalSpy>
 // KWin
 #include "../../src/client/compositor.h"
 #include "../../src/client/connection_thread.h"
@@ -264,6 +251,7 @@ void TestWaylandSurface::testDamage()
     QSignalSpy serverSurfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWayland::Server::SurfaceInterface*)));
     QVERIFY(serverSurfaceCreated.isValid());
     KWayland::Client::Surface *s = m_compositor->createSurface();
+    s->setScale(2);
     QVERIFY(serverSurfaceCreated.wait());
     KWayland::Server::SurfaceInterface *serverSurface = serverSurfaceCreated.first().first().value<KWayland::Server::SurfaceInterface*>();
     QVERIFY(serverSurface);
@@ -271,6 +259,7 @@ void TestWaylandSurface::testDamage()
     QVERIFY(serverSurface->parentResource());
     QVERIFY(!serverSurface->isMapped());
 
+    QSignalSpy committedSpy(serverSurface, SIGNAL(committed()));
     QSignalSpy damageSpy(serverSurface, SIGNAL(damaged(QRegion)));
     QVERIFY(damageSpy.isValid());
 
@@ -282,21 +271,24 @@ void TestWaylandSurface::testDamage()
     QCoreApplication::processEvents();
     QVERIFY(damageSpy.isEmpty());
     QVERIFY(!serverSurface->isMapped());
+    QCOMPARE(committedSpy.count(), 1);
 
     QImage img(QSize(10, 10), QImage::Format_ARGB32_Premultiplied);
     img.fill(Qt::black);
     auto b = m_shm->createBuffer(img);
-    s->attachBuffer(b);
+    s->attachBuffer(b, QPoint(55, 55));
     s->damage(QRect(0, 0, 10, 10));
     s->commit(KWayland::Client::Surface::CommitFlag::None);
     QVERIFY(damageSpy.wait());
-    QCOMPARE(serverSurface->damage(), QRegion(0, 0, 10, 10));
-    QCOMPARE(damageSpy.first().first().value<QRegion>(), QRegion(0, 0, 10, 10));
+    QCOMPARE(serverSurface->offset(), QPoint(55, 55)); // offset is surface local so scale doesn't change this
+    QCOMPARE(serverSurface->damage(), QRegion(0, 0, 5, 5)); // scale is 2
+    QCOMPARE(damageSpy.first().first().value<QRegion>(), QRegion(0, 0, 5, 5));
     QVERIFY(serverSurface->isMapped());
+    QCOMPARE(committedSpy.count(), 2);
 
     // damage multiple times
     QRegion testRegion(5, 8, 3, 6);
-    testRegion = testRegion.united(QRect(10, 20, 30, 15));
+    testRegion = testRegion.united(QRect(10, 11, 6, 1));
     img = QImage(QSize(40, 35), QImage::Format_ARGB32_Premultiplied);
     img.fill(Qt::black);
     b = m_shm->createBuffer(img);
@@ -308,6 +300,40 @@ void TestWaylandSurface::testDamage()
     QCOMPARE(serverSurface->damage(), testRegion);
     QCOMPARE(damageSpy.first().first().value<QRegion>(), testRegion);
     QVERIFY(serverSurface->isMapped());
+    QCOMPARE(committedSpy.count(), 3);
+
+    // damage buffer
+    const QRegion testRegion2(30, 40, 22, 4);
+    const QRegion cmpRegion2(15, 20, 11, 2); // divided by scale factor
+    img = QImage(QSize(80, 70), QImage::Format_ARGB32_Premultiplied);
+    img.fill(Qt::black);
+    b = m_shm->createBuffer(img);
+    s->attachBuffer(b);
+    s->damageBuffer(testRegion2);
+    damageSpy.clear();
+    s->commit(KWayland::Client::Surface::CommitFlag::None);
+    QVERIFY(damageSpy.wait());
+    QCOMPARE(serverSurface->damage(), cmpRegion2);
+    QCOMPARE(damageSpy.first().first().value<QRegion>(), cmpRegion2);
+    QVERIFY(serverSurface->isMapped());
+
+    // combined regular damage and damaged buffer
+    const QRegion testRegion3 = testRegion.united(cmpRegion2);
+    img = QImage(QSize(80, 70), QImage::Format_ARGB32_Premultiplied);
+    img.fill(Qt::black);
+    b = m_shm->createBuffer(img);
+    s->attachBuffer(b);
+    s->damage(testRegion);
+    s->damageBuffer(testRegion2);
+    damageSpy.clear();
+    s->commit(KWayland::Client::Surface::CommitFlag::None);
+    QVERIFY(damageSpy.wait());
+    QVERIFY(serverSurface->damage() != testRegion);
+    QVERIFY(serverSurface->damage() != testRegion2);
+    QVERIFY(serverSurface->damage() != cmpRegion2);
+    QCOMPARE(serverSurface->damage(), testRegion3);
+    QCOMPARE(damageSpy.first().first().value<QRegion>(), testRegion3);
+    QVERIFY(serverSurface->isMapped());
 }
 
 void TestWaylandSurface::testFrameCallback()
@@ -355,9 +381,13 @@ void TestWaylandSurface::testAttachBuffer()
     QImage blue(24, 24, QImage::Format_ARGB32_Premultiplied);
     blue.fill(QColor(0, 0, 255, 128));
 
-    wl_buffer *blackBuffer = *(m_shm->createBuffer(black).data());
-    auto redBuffer = m_shm->createBuffer(red);
-    auto blueBuffer = m_shm->createBuffer(blue).toStrongRef();
+    QSharedPointer<KWayland::Client::Buffer> blackBufferPtr = m_shm->createBuffer(black).toStrongRef();
+    QVERIFY(blackBufferPtr);
+    wl_buffer *blackBuffer = *(blackBufferPtr.data());
+    QSharedPointer<KWayland::Client::Buffer> redBuffer = m_shm->createBuffer(red).toStrongRef();
+    QVERIFY(redBuffer);
+    QSharedPointer<KWayland::Client::Buffer> blueBuffer = m_shm->createBuffer(blue).toStrongRef();
+    QVERIFY(blueBuffer);
 
     QCOMPARE(blueBuffer->format(), KWayland::Client::Buffer::Format::ARGB32);
     QCOMPARE(blueBuffer->size(), blue.size());
@@ -481,6 +511,7 @@ void TestWaylandSurface::testMultipleSurfaces()
     using namespace KWayland::Client;
     using namespace KWayland::Server;
     Registry registry;
+    registry.setEventQueue(m_queue);
     QSignalSpy shmSpy(&registry, SIGNAL(shmAnnounced(quint32,quint32)));
     registry.create(m_connection->display());
     QVERIFY(registry.isValid());
@@ -738,7 +769,8 @@ void TestWaylandSurface::testScale()
     //attach a buffer of 100x100, our scale is 4, so this should be a size of 25x25
     QImage red(100, 100, QImage::Format_ARGB32_Premultiplied);
     red.fill(QColor(255, 0, 0, 128));
-    auto redBuffer = m_shm->createBuffer(red);
+    QSharedPointer<Buffer> redBuffer = m_shm->createBuffer(red).toStrongRef();
+    QVERIFY(redBuffer);
     s->attachBuffer(redBuffer.data());
     s->damage(QRect(0,0, 25,25));
     s->commit(Surface::CommitFlag::None);
@@ -762,7 +794,8 @@ void TestWaylandSurface::testScale()
     //set scale and size in one commit, buffer is 50x50 at scale 2 so size should be 25x25
     QImage blue(50, 50, QImage::Format_ARGB32_Premultiplied);
     red.fill(QColor(255, 0, 0, 128));
-    auto blueBuffer = m_shm->createBuffer(blue);
+    QSharedPointer<Buffer> blueBuffer = m_shm->createBuffer(blue).toStrongRef();
+    QVERIFY(blueBuffer);
     s->attachBuffer(blueBuffer.data());
     s->setScale(2);
     s->commit(Surface::CommitFlag::None);
@@ -1143,12 +1176,12 @@ void TestWaylandSurface::testInhibit()
 
     // creating a second idle inhibition should not trigger the signal
     QScopedPointer<IdleInhibitor> inhibitor2(m_idleInhibitManager->createInhibitor(s.data()));
-    QVERIFY(!inhibitsChangedSpy.wait());
+    QVERIFY(!inhibitsChangedSpy.wait(500));
     QCOMPARE(serverSurface->inhibitsIdle(), true);
 
     // and also deleting the first inhibitor should not yet change the inhibition
     inhibitor1.reset();
-    QVERIFY(!inhibitsChangedSpy.wait());
+    QVERIFY(!inhibitsChangedSpy.wait(500));
     QCOMPARE(serverSurface->inhibitsIdle(), true);
 
     // but deleting also the second inhibitor should trigger
