@@ -1,26 +1,13 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "seat.h"
 #include "event_queue.h"
 #include "keyboard.h"
 #include "pointer.h"
+#include "touch.h"
 #include "wayland_pointer_p.h"
 // Wayland
 #include <wayland-client-protocol.h>
@@ -30,7 +17,7 @@ namespace KWayland
 namespace Client
 {
 
-class Seat::Private
+class Q_DECL_HIDDEN Seat::Private
 {
 public:
     Private(Seat *q);
@@ -207,14 +194,20 @@ Pointer *Seat::createPointer(QObject *parent)
     return p;
 }
 
-#if 0
-wl_touch *Seat::createTouch()
+Touch *Seat::createTouch(QObject *parent)
 {
     Q_ASSERT(isValid());
     Q_ASSERT(d->capabilityTouch);
-    return wl_seat_get_touch(d->seat);
+    Touch *t = new Touch(parent);
+    connect(this, &Seat::interfaceAboutToBeReleased, t, &Touch::release);
+    connect(this, &Seat::interfaceAboutToBeDestroyed, t, &Touch::destroy);
+    auto w = wl_seat_get_touch(d->seat);
+    if (d->queue) {
+        d->queue->addProxy(w);
+    }
+    t->setup(w);
+    return t;
 }
-#endif
 
 void Seat::Private::setName(const QString &n)
 {
