@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "shell.h"
 #include "event_queue.h"
 #include "output.h"
@@ -26,7 +12,6 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 // Qt
 #include <QGuiApplication>
 #include <QVector>
-#include <QWindow>
 #include <qpa/qplatformnativeinterface.h>
 // Wayland
 #include <wayland-client-protocol.h>
@@ -164,9 +149,6 @@ ShellSurface *ShellSurface::fromWindow(QWindow *window)
     if (!window) {
         return nullptr;
     }
-    if (!QGuiApplication::platformName().contains(QStringLiteral("wayland"), Qt::CaseInsensitive)) {
-        return nullptr;
-    }
     QPlatformNativeInterface *native = qApp->platformNativeInterface();
     if (!native) {
         return nullptr;
@@ -237,7 +219,7 @@ void ShellSurface::destroy()
     d->surface.destroy();
 }
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
+#ifndef K_DOXYGEN
 const struct wl_shell_surface_listener ShellSurface::Private::s_listener = {
     pingCallback,
     configureCallback,
@@ -366,6 +348,16 @@ void ShellSurface::requestResize(Seat *seat, quint32 serial, Qt::Edges edges)
     wl_shell_surface_resize(d->surface, *seat, serial, wlEdge);
 }
 
+void ShellSurface::setTitle(const QString &title)
+{
+    wl_shell_surface_set_title(d->surface, title.toUtf8().constData());
+}
+
+void ShellSurface::setWindowClass(const QByteArray &windowClass)
+{
+    wl_shell_surface_set_class(d->surface, windowClass.constData());
+}
+
 QSize ShellSurface::size() const
 {
     return d->size;
