@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_SURFACE_H
 #define WAYLAND_SURFACE_H
 
@@ -39,6 +25,7 @@ namespace KWayland
 namespace Client
 {
 
+class Output;
 class Region;
 
 /**
@@ -105,10 +92,8 @@ public:
      * that the instance can be deleted or set up to a new wl_surface interface
      * once there is a new connection available.
      *
-     * It is suggested to connect this method to ConnectionThread::connectionDied:
-     * @code
-     * connect(connection, &ConnectionThread::connectionDied, surface, &Surface::destroy);
-     * @endcode
+     * This method is automatically invoked when the Registry which created this
+     * Surface gets destroyed.
      *
      * @see release
      **/
@@ -150,12 +135,26 @@ public:
     void commit(CommitFlag flag = CommitFlag::FrameCallback);
     /**
      * Mark @p rect as damaged for the next frame.
+     * @see damageBuffer
      **/
     void damage(const QRect &rect);
     /**
      * Mark @p region as damaged for the next frame.
+     * @see damageBuffer
      **/
     void damage(const QRegion &region);
+    /**
+     * Mark @p rect in buffer coordinates as damaged for the next frame.
+     * @see damage
+     * @since 5.59
+     **/
+    void damageBuffer(const QRect &rect);
+    /**
+     * Mark @p region in buffer coordinates as damaged for the next frame.
+     * @see damage
+     * @since 5.59
+     **/
+    void damageBuffer(const QRegion &region);
     /**
      * Attaches the @p buffer to this Surface for the next frame.
      * @param buffer The buffer to attach to this Surface
@@ -237,6 +236,14 @@ public:
      **/
     quint32 id() const;
 
+    /**
+     * @returns All Outputs the Surface is on, may be none.
+     * @see outputEntered
+     * @see outputLeft
+     * @since 5.27
+     **/
+    QVector<Output *> outputs() const;
+
     /**
      * All Surfaces which are currently created.
      * TODO: KF6 return QList<Surface*> instead of const-ref
@@ -258,6 +265,28 @@ Q_SIGNALS:
     void frameRendered();
     void sizeChanged(const QSize&);
 
+    /**
+     * Emitted whenever a change in the Surface (e.g. creation, movement, resize) results in
+     * a part of the Surface being within the scanout region of the Output @p o.
+     *
+     * @param o The Output the Surface intersects with
+     * @see outputLeft
+     * @see outputs
+     * @since 5.27
+     **/
+    void outputEntered(KWayland::Client::Output *o);
+
+    /**
+     * Emitted whenever a change in the Surface (e.g. creation, movement, resize, unmapping)
+     * results in the Surface no longer being within the scanout region of the Output @p o.
+     *
+     * @param o The Output the Surface no longer intersects with
+     * @see outputEntered
+     * @see outputs
+     * @since 5.27
+     **/
+    void outputLeft(KWayland::Client::Output *o);
+
 private:
     class Private;
     QScopedPointer<Private> d;
