@@ -1,22 +1,8 @@
-/****************************************************************************
-Copyright 2016  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2016 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-****************************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef KWAYLAND_CLIENT_XDG_SHELL_H
 #define KWAYLAND_CLIENT_XDG_SHELL_H
 
@@ -141,6 +127,8 @@ private:
     QScopedPointer<Private> d;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(XdgPositioner::Constraints)
+
 /**
  * @short Wrapper for the xdg_shell interface.
  *
@@ -511,6 +499,8 @@ private:
     QScopedPointer<Private> d;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(XdgShellSurface::States)
+
 /**
  * A XdgShellPopup is a short-lived, temporary surface that can be
  * used to implement menus. It takes an explicit grab on the surface
@@ -645,9 +635,6 @@ private:
 }
 }
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(KWayland::Client::XdgShellSurface::States)
-Q_DECLARE_OPERATORS_FOR_FLAGS(KWayland::Client::XdgPositioner::Constraints)
-
 Q_DECLARE_METATYPE(KWayland::Client::XdgPositioner)
 Q_DECLARE_METATYPE(KWayland::Client::XdgShellSurface::State)
 Q_DECLARE_METATYPE(KWayland::Client::XdgShellSurface::States)
