@@ -1,32 +1,21 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "buffer_interface.h"
 #include "display.h"
-#include "logging_p.h"
+#include "logging.h"
 #include "surface_interface.h"
+#include "linuxdmabuf_v1_interface.h"
 // Wayland
 #include <wayland-server.h>
 // EGL
 #include <EGL/egl.h>
 #include <QtGui/qopengl.h>
 
+#include "drm_fourcc.h"
+
 namespace KWayland
 {
 namespace Server
@@ -47,6 +36,7 @@ public:
     QImage createImage();
     wl_resource *buffer;
     wl_shm_buffer *shmBuffer;
+    LinuxDmabufBuffer *dmabufBuffer;
     SurfaceInterface *surface;
     int refCount;
     QSize size;
@@ -103,11 +93,15 @@ void BufferInterface::Private::imageBufferCleanupHandler(void *info)
 BufferInterface::Private::Private(BufferInterface *q, wl_resource *resource, SurfaceInterface *parent)
     : buffer(resource)
     , shmBuffer(wl_shm_buffer_get(resource))
+    , dmabufBuffer(nullptr)
     , surface(parent)
     , refCount(0)
     , alpha(false)
     , q(q)
 {
+    if (!shmBuffer && wl_resource_instance_of(resource, &wl_buffer_interface, LinuxDmabufUnstableV1Interface::bufferImplementation())) {
+        dmabufBuffer = static_cast<LinuxDmabufBuffer *>(wl_resource_get_user_data(resource));
+    }
     s_buffers << this;
     listener.notify = destroyListenerCallback;
     listener.link.prev = nullptr;
@@ -125,6 +119,43 @@ BufferInterface::Private::Private(BufferInterface *q, wl_resource *resource, Sur
             alpha = false;
             break;
         }
+    } else if (dmabufBuffer) {
+        switch (dmabufBuffer->format()) {
+        case DRM_FORMAT_ARGB4444:
+        case DRM_FORMAT_ABGR4444:
+        case DRM_FORMAT_RGBA4444:
+        case DRM_FORMAT_BGRA4444:
+
+        case DRM_FORMAT_ARGB1555:
+        case DRM_FORMAT_ABGR1555:
+        case DRM_FORMAT_RGBA5551:
+        case DRM_FORMAT_BGRA5551:
+
+        case DRM_FORMAT_ARGB8888:
+        case DRM_FORMAT_ABGR8888:
+        case DRM_FORMAT_RGBA8888:
+        case DRM_FORMAT_BGRA8888:
+
+        case DRM_FORMAT_ARGB2101010:
+        case DRM_FORMAT_ABGR2101010:
+        case DRM_FORMAT_RGBA1010102:
+        case DRM_FORMAT_BGRA1010102:
+
+        case DRM_FORMAT_XRGB8888_A8:
+        case DRM_FORMAT_XBGR8888_A8:
+        case DRM_FORMAT_RGBX8888_A8:
+        case DRM_FORMAT_BGRX8888_A8:
+        case DRM_FORMAT_RGB888_A8:
+        case DRM_FORMAT_BGR888_A8:
+        case DRM_FORMAT_RGB565_A8:
+        case DRM_FORMAT_BGR565_A8:
+            alpha = true;
+            break;
+        default:
+            alpha = false;
+            break;
+        }
+        size = dmabufBuffer->size();
     } else if (parent) {
         EGLDisplay eglDisplay = parent->global()->display()->eglDisplay();
         static bool resolved = false;
@@ -224,7 +255,7 @@ QImage::Format BufferInterface::Private::format() const
     }
     switch (wl_shm_buffer_get_format(shmBuffer)) {
     case WL_SHM_FORMAT_ARGB8888:
-        return QImage::Format_ARGB32;
+        return QImage::Format_ARGB32_Premultiplied;
     case WL_SHM_FORMAT_XRGB8888:
         return QImage::Format_RGB32;
     default:
@@ -234,7 +265,7 @@ QImage::Format BufferInterface::Private::format() const
 
 QImage BufferInterface::data()
 {
-    return std::move(d->createImage());
+    return d->createImage();
 }
 
 QImage BufferInterface::Private::createImage()
@@ -252,12 +283,12 @@ QImage BufferInterface::Private::createImage()
     s_accessedBuffer = this;
     s_accessCounter++;
     wl_shm_buffer_begin_access(shmBuffer);
-    return std::move(QImage((const uchar*)wl_shm_buffer_get_data(shmBuffer),
-                            size.width(),
-                            size.height(),
-                            wl_shm_buffer_get_stride(shmBuffer),
-                            imageFormat,
-                            &imageBufferCleanupHandler, this));
+    return QImage((const uchar*)wl_shm_buffer_get_data(shmBuffer),
+                  size.width(),
+                  size.height(),
+                  wl_shm_buffer_get_stride(shmBuffer),
+                  imageFormat,
+                  &imageBufferCleanupHandler, this);
 }
 
 bool BufferInterface::isReferenced() const
@@ -275,6 +306,11 @@ wl_shm_buffer *BufferInterface::shmBuffer()
     return d->shmBuffer;
 }
 
+LinuxDmabufBuffer *BufferInterface::linuxDmabufBuffer()
+{
+    return d->dmabufBuffer;
+}
+
 wl_resource *BufferInterface::resource() const
 {
     return d->buffer;
