@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "clientconnection.h"
 #include "display.h"
 // Qt
@@ -66,7 +52,9 @@ ClientConnection::Private::Private(wl_client *c, Display *display, ClientConnect
 
 ClientConnection::Private::~Private()
 {
-    wl_list_remove(&listener.link);
+    if (client) {
+        wl_list_remove(&listener.link);
+    }
     s_allClients.removeAt(s_allClients.indexOf(this));
 }
 
@@ -80,9 +68,12 @@ void ClientConnection::Private::destroyListenerCallback(wl_listener *listener, v
         }
     );
     Q_ASSERT(it != s_allClients.constEnd());
-    auto q = (*it)->q;
+    auto p = (*it);
+    auto q = p->q;
+    p->client = nullptr;
+    wl_list_remove(&p->listener.link);
     emit q->disconnected(q);
-    delete q;
+    q->deleteLater();
 }
 
 ClientConnection::ClientConnection(wl_client *c, Display *parent)
@@ -95,21 +86,33 @@ ClientConnection::~ClientConnection() = default;
 
 void ClientConnection::flush()
 {
+    if (!d->client) {
+        return;
+    }
     wl_client_flush(d->client);
 }
 
 void ClientConnection::destroy()
 {
+    if (!d->client) {
+        return;
+    }
     wl_client_destroy(d->client);
 }
 
 wl_resource *ClientConnection::createResource(const wl_interface *interface, quint32 version, quint32 id)
 {
+    if (!d->client) {
+        return nullptr;
+    }
     return wl_resource_create(d->client, interface, version, id);
 }
 
 wl_resource *ClientConnection::getResource(quint32 id)
 {
+    if (!d->client) {
+        return nullptr;
+    }
     return wl_client_get_object(d->client, id);
 }
 
