@@ -1,23 +1,9 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
-Copyright 2018  David Edmundson <davidedmundson@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2018 David Edmundson <davidedmundson@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_SERVER_DISPLAY_H
 #define WAYLAND_SERVER_DISPLAY_H
 
@@ -92,6 +78,8 @@ class XdgOutputManagerInterface;
 class XdgDecorationManagerInterface;
 class EglStreamControllerInterface;
 class KeyStateInterface;
+class LinuxDmabufUnstableV1Interface;
+class TabletManagerInterface;
 
 /**
  * @brief Class holding the Wayland server display loop.
@@ -282,6 +270,13 @@ public:
      **/
     ServerSideDecorationPaletteManagerInterface *createServerSideDecorationPaletteManager(QObject *parent = nullptr);
 
+    /**
+     * Creates the LinuxDmabufUnstableV1Interface in interface @p version.
+     *
+     * @returns A pointer to the created interface
+     **/
+    LinuxDmabufUnstableV1Interface *createLinuxDmabufInterface(QObject *parent = nullptr);
+
     /**
      * Creates the XdgOutputManagerInterface
      *
@@ -316,6 +311,13 @@ public:
      */
     EglStreamControllerInterface *createEglStreamControllerInterface(QObject *parent = nullptr);
 
+    /**
+     * Creates the entry point to support wacom-like tablets and pens.
+     *
+     * @since 5.67
+     */
+    TabletManagerInterface *createTabletManagerInterface(QObject *parent = nullptr);
+
     /**
      * Gets the ClientConnection for the given @p client.
      * If there is no ClientConnection yet for the given @p client, it will be created.
