@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_SERVER_GLOBAL_H
 #define WAYLAND_SERVER_GLOBAL_H
 
@@ -90,6 +76,14 @@ public:
      **/
     operator wl_global*() const;
 
+Q_SIGNALS:
+    /**
+     * This signal is emitted when the client is in the process of removing the wl_global.
+     * At the time the signal is emitted the global is still valid and allows to perform
+     * cleanup tasks.
+     */
+    void aboutToDestroyGlobal();
+
 protected:
     class Private;
     explicit Global(Private *d, QObject *parent = nullptr);
