@@ -1,26 +1,12 @@
-/********************************************************************
-Copyright © 2019 Roman Gilg <subdiff@gmail.com>
-Copyright © 2018 Fredrik Höglund <fredrik@kde.org>
+/*
+    SPDX-FileCopyrightText: 2019 Roman Gilg <subdiff@gmail.com>
+    SPDX-FileCopyrightText: 2018 Fredrik Höglund <fredrik@kde.org>
 
-Based on the libweston implementation,
-Copyright © 2014, 2015 Collabora, Ltd.
+    Based on the libweston implementation,
+    SPDX-FileCopyrightText: 2014, 2015 Collabora, Ltd.
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "linuxdmabuf_v1_interface.h"
 
 #include "drm_fourcc.h"
@@ -28,7 +14,6 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "wayland-linux-dmabuf-unstable-v1-server-protocol.h"
 #include "wayland-server-protocol.h"
 
-#include <KWayland/Server/kwaylandserver_export.h>
 
 #include <QVector>
 
