@@ -1,33 +1,19 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "seat_interface.h"
 #include "seat_interface_p.h"
 #include "display.h"
 #include "datadevice_interface.h"
 #include "datasource_interface.h"
-#include "keyboard_interface.h"
 #include "keyboard_interface_p.h"
-#include "pointer_interface.h"
 #include "pointer_interface_p.h"
 #include "surface_interface.h"
 #include "textinput_interface_p.h"
+// Qt
+#include <QFile>
 // Wayland
 #ifndef WL_SEAT_NAME_SINCE_VERSION
 #define WL_SEAT_NAME_SINCE_VERSION 2
@@ -536,7 +522,7 @@ void SeatInterface::Private::getKeyboard(wl_client *client, wl_resource *resourc
     }
     keyboard->repeatInfo(keys.keyRepeat.charactersPerSecond, keys.keyRepeat.delay);
     if (keys.keymap.xkbcommonCompatible) {
-        keyboard->setKeymap(keys.keymap.fd, keys.keymap.size);
+        keyboard->setKeymap(keys.keymap.content);
     }
     keyboards << keyboard;
     if (keys.focus.surface && keys.focus.surface->client() == clientConnection) {
@@ -1161,14 +1147,28 @@ void SeatInterface::setFocusedKeyboardSurface(SurfaceInterface *surface)
     }
 }
 
+#if KWAYLANDSERVER_BUILD_DEPRECATED_SINCE(5, 69)
 void SeatInterface::setKeymap(int fd, quint32 size)
+{
+    QFile file;
+    if (!file.open(fd, QIODevice::ReadOnly)) {
+        return;
+    }
+    const char *address = reinterpret_cast<char*>(file.map(0, size));
+    if (!address) {
+        return;
+    }
+    setKeymapData(QByteArray(address, size));
+}
+#endif
+
+void SeatInterface::setKeymapData(const QByteArray &content)
 {
     Q_D();
     d->keys.keymap.xkbcommonCompatible = true;
-    d->keys.keymap.fd = fd;
-    d->keys.keymap.size = size;
+    d->keys.keymap.content = content;
     for (auto it = d->keyboards.constBegin(); it != d->keyboards.constEnd(); ++it) {
-        (*it)->setKeymap(fd, size);
+        (*it)->setKeymap(content);
     }
 }
 
@@ -1225,17 +1225,19 @@ bool SeatInterface::isKeymapXkbCompatible() const
     return d->keys.keymap.xkbcommonCompatible;
 }
 
+#if KWAYLANDSERVER_BUILD_DEPRECATED_SINCE(5, 69)
 int SeatInterface::keymapFileDescriptor() const
 {
-    Q_D();
-    return d->keys.keymap.fd;
+    return -1;
 }
+#endif
 
+#if KWAYLANDSERVER_BUILD_DEPRECATED_SINCE(5, 69)
 quint32 SeatInterface::keymapSize() const
 {
-    Q_D();
-    return d->keys.keymap.size;
+    return 0;
 }
+#endif
 
 quint32 SeatInterface::depressedModifiers() const
 {
